<p align="center">
  <img src="https://i.imgur.com/Fo9EmnK.png" width="400" />
</p>

<p align="center">
  <a href="https://pypi.python.org/pypi/risk-network"><img src="https://img.shields.io/pypi/v/risk-network.svg" alt="pypiv"></a>
  <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/python-3.8+-blue.svg" alt="Python 3.8+"></a>
  <a href="https://raw.githubusercontent.com/irahorecka/chrono24/main/LICENSE"><img src="https://img.shields.io/badge/License-GPLv3-blue.svg" alt="License: GPL v3"></a>
</p>

## RISK

#### RISK Infers Spatial Kinships

RISK is a software tool for visualizing spatial relationships in networks. It aims to enhance network analysis by integrating advanced network annotation algorithms, such as Louvain and Markov Clustering, to identify key functional modules and pathways.

## Features

- Spatial analysis of biological networks
- Functional enrichment detection
- Optimized performance

## Example

*Saccharomyces cerevisiae* proteins oriented by physical interactions discovered through affinity enrichment and mass spectrometry (Michaelis et al., 2023).

![PPI Network Demo](https://i.imgur.com/NnyK6nO.png)

## Installation

Coming soon...

## Usage

Coming soon...

## License

This project is licensed under the GPL-3.0 license.
